==> kubernetes-model-networking-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/networking/v1beta1/HTTPIngressRuleValueBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class HTTPIngressRuleValueBuilder extends io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluentImpl<io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue,io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder> {

    io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluent<?> fluent;
    Boolean validationEnabled;

    public HTTPIngressRuleValueBuilder() {
        this(true);
    }

    public HTTPIngressRuleValueBuilder(Boolean validationEnabled) {
        this(new HTTPIngressRuleValue(), validationEnabled);
    }

    public HTTPIngressRuleValueBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluent<?> fluent) {
        this(fluent, true);
    }

    public HTTPIngressRuleValueBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new HTTPIngressRuleValue(), validationEnabled);
    }

    public HTTPIngressRuleValueBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue instance) {
        this(fluent, instance, true);
    }

    public HTTPIngressRuleValueBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withPaths(instance.getPaths()); 
        this.validationEnabled = validationEnabled; 
    }

    public HTTPIngressRuleValueBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue instance) {
        this(instance,true);
    }

    public HTTPIngressRuleValueBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withPaths(instance.getPaths()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue build() {
        HTTPIngressRuleValue buildable = new HTTPIngressRuleValue(fluent.getPaths());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        HTTPIngressRuleValueBuilder that = (HTTPIngressRuleValueBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-networking-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/networking/v1beta1/HTTPIngressRuleValueBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class HTTPIngressRuleValueBuilder extends io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluentImpl<io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue,io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder> {

    io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluent<?> fluent;
    Boolean validationEnabled;

    public HTTPIngressRuleValueBuilder() {
        this(true);
    }

    public HTTPIngressRuleValueBuilder(Boolean validationEnabled) {
        this(new HTTPIngressRuleValue(), validationEnabled);
    }

    public HTTPIngressRuleValueBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluent<?> fluent) {
        this(fluent, true);
    }

    public HTTPIngressRuleValueBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new HTTPIngressRuleValue(), validationEnabled);
    }

    public HTTPIngressRuleValueBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue instance) {
        this(fluent, instance, true);
    }

    public HTTPIngressRuleValueBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withPaths(instance.getPaths()); 
        this.validationEnabled = validationEnabled; 
    }

    public HTTPIngressRuleValueBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue instance) {
        this(instance,true);
    }

    public HTTPIngressRuleValueBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withPaths(instance.getPaths()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue build() {
        HTTPIngressRuleValue buildable = new HTTPIngressRuleValue(fluent.getPaths());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        HTTPIngressRuleValueBuilder that = (HTTPIngressRuleValueBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
